@@ -1,6 +1,6 @@
 from pathlib import Path
 from shutil import rmtree
-from typing import Optional, Tuple
+from typing import Optional
 from urllib.parse import urlparse
 
 import click
@@ -10,12 +10,13 @@ from tartufo.scanner import GitRepoScanner
 
 
 @click.command("scan-remote-repo")
-@click.option("--since-commit", help="Only scan from a given commit hash.")
+@click.option("--since-commit", help="Only scan from a given commit hash.", hidden=True)
 @click.option(
     "--max-depth",
     default=1000000,
     show_default=True,
     help="The max commit depth to go back when searching for secrets.",
+    hidden=True,
 )
 @click.option("--branch", help="Specify a branch name to scan only that branch.")
 @click.option(
@@ -51,15 +52,13 @@ def main(
     branch: Optional[str],
     work_dir: Optional[str],
     include_submodules: bool,
-) -> Tuple[str, GitRepoScanner]:
+) -> GitRepoScanner:
     """Automatically clone and scan a remote git repository."""
     git_options = types.GitOptions(
         since_commit=since_commit,
         max_depth=max_depth,
-        branch=branch,
-        fetch=False,
+        branch=None,
         include_submodules=include_submodules,
-        is_remote=True,
     )
     repo_path: Optional[Path] = None
     if work_dir:
@@ -70,9 +69,11 @@ def main(
         repo_path.mkdir(parents=True)
     scanner = None
     try:
-        repo_path = util.clone_git_repo(git_url, repo_path)
+        repo_path, origin = util.clone_git_repo(git_url, repo_path)
+        if branch:
+            git_options.branch = f"{origin}/{branch}"
         scanner = GitRepoScanner(options, git_options, str(repo_path))
-        scanner.scan()
+        util.process_issues(git_url, scanner, options)
     except types.GitException as exc:
         util.fail(f"Error cloning remote repo: {exc}", ctx)
     except types.TartufoException as exc:
@@ -80,4 +81,4 @@ def main(
     finally:
         if repo_path and repo_path.exists():
             rmtree(str(repo_path), onerror=util.del_rw)
-    return (git_url, scanner)  # type: ignore
+    return scanner  # type: ignore
